.. _index:

Radontea is a Python library for computerized tomographic
image reconstruction. Radontea implements several iterative
and non-iterative reconstruction algorithms.
This is the documentaion of radontea version |release|.

Documentation
=============


.. toctree::
   :maxdepth: 4

   sec_introduction
   sec_code_reference
   sec_examples

.. toctree::
   :maxdepth: 1

   sec_changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
   

